(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('prop-types'), require('fbjs/lib/shallowEqual')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react', 'prop-types', 'fbjs/lib/shallowEqual'], factory) :
  (factory((global.ReactScreenSize = {}),global.React,global.PropTypes,global.shallowEqual));
}(this, (function (exports,React,PropTypes,shallowEqual) { 'use strict';

  React = React && React.hasOwnProperty('default') ? React['default'] : React;
  PropTypes = PropTypes && PropTypes.hasOwnProperty('default') ? PropTypes['default'] : PropTypes;
  shallowEqual = shallowEqual && shallowEqual.hasOwnProperty('default') ? shallowEqual['default'] : shallowEqual;

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    };

    return _extends.apply(this, arguments);
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};
      var ownKeys = Object.keys(source);

      if (typeof Object.getOwnPropertySymbols === 'function') {
        ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) {
          return Object.getOwnPropertyDescriptor(source, sym).enumerable;
        }));
      }

      ownKeys.forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    }

    return target;
  }

  function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    subClass.__proto__ = superClass;
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }

    return self;
  }

  var greaterThanMedias = {
    gtXs: '(min-width: 601px)',
    gtSm: '(min-width: 961px)',
    gtMd: '(min-width: 1281px)',
    gtLg: '(min-width: 1921px)'
  };
  var strictMedias = {
    xs: '(max-width: 600px)',
    sm: '(max-width: 960px) and (min-width: 601px)',
    md: '(max-width: 1280px) and (min-width: 961px)',
    lg: '(max-width: 1920px) and (min-width: 1281px)'
  };
  var defaultMedias = _objectSpread({}, greaterThanMedias, strictMedias);

  var gtKeys = Object.keys(greaterThanMedias);
  var defaultScreenSize = {
    xs: false,
    gtXs: true,
    sm: false,
    gtSm: true,
    md: true,
    gtMd: true,
    lg: false,
    gtLg: false
  };

  var Provider =
  /*#__PURE__*/
  function () {
    function Provider(medias, screenSize, matchMedia) {
      var _this = this;

      if (medias === void 0) {
        medias = {};
      }

      if (screenSize === void 0) {
        screenSize = {};
      }

      if (matchMedia === void 0) {
        matchMedia = window.matchMedia;
      }

      this.listeners = [];
      this.medias = Object.assign({}, defaultMedias, medias);
      this.screenSize = Object.assign({}, defaultScreenSize, screenSize);
      this.mediaQueryLists = {};
      Object.keys(this.medias).forEach(function (key) {
        _this.mediaQueryLists[key] = matchMedia(_this.medias[key]);
      });
      gtKeys.forEach(function (key) {
        _this.mediaQueryLists[key].addListener(function () {
          return _this.update();
        });
      });
    }

    var _proto = Provider.prototype;

    _proto.getScreenSize = function getScreenSize() {
      return this.screenSize;
    };

    _proto.update = function update() {
      var _this2 = this;

      this.screenSize = Object.assign({}, this.screenSize);
      Object.keys(this.screenSize).forEach(function (key) {
        _this2.screenSize[key] = _this2.mediaQueryLists[key].matches;
      });
      this.listeners.forEach(function (listener) {
        return listener();
      });
    };

    _proto.subscribe = function subscribe(listener) {
      var _this3 = this;

      this.listeners.push(listener);
      return function () {
        _this3.listeners.splice(_this3.listeners.indexOf(listener), 1);
      };
    };

    return Provider;
  }();

  var MediaProvider =
  /*#__PURE__*/
  function (_React$Component) {
    _inheritsLoose(MediaProvider, _React$Component);

    function MediaProvider() {
      return _React$Component.apply(this, arguments) || this;
    }

    var _proto = MediaProvider.prototype;

    _proto.getChildContext = function getChildContext() {
      return {
        screenSizeProvider: this.provider
      };
    };

    _proto.componentWillMount = function componentWillMount() {
      this.provider = new Provider(this.props.medias, this.props.screenSize, this.props.matchMedia);
    };

    _proto.render = function render() {
      return this.props.children;
    };

    return MediaProvider;
  }(React.Component);

  Object.defineProperty(MediaProvider, "childContextTypes", {
    configurable: true,
    enumerable: true,
    writable: true,
    value: {
      screenSizeProvider: PropTypes.object.isRequired
    }
  });

  var connectScreenSize = function connectScreenSize(mapScreenToProps) {
    return function (ComposedComponent) {
      var ConnectScreenSize =
      /*#__PURE__*/
      function (_React$Component) {
        _inheritsLoose(ConnectScreenSize, _React$Component);

        function ConnectScreenSize(props, context) {
          var _this;

          _this = _React$Component.call(this, props) || this;
          Object.defineProperty(_assertThisInitialized(_this), "updateComputedProps", {
            configurable: true,
            enumerable: true,
            writable: true,
            value: function value() {
              var computedProps = mapScreenToProps(_this.context.screenSizeProvider.getScreenSize(), _this.props);

              if (!shallowEqual(computedProps, _this.state.computedProps)) {
                _this.setState({
                  computedProps: computedProps
                });
              }
            }
          });
          _this.state = {
            computedProps: mapScreenToProps(context.screenSizeProvider.getScreenSize(), props)
          };
          return _this;
        }

        var _proto = ConnectScreenSize.prototype;

        _proto.componentDidMount = function componentDidMount() {
          this.unsubscribe = this.context.screenSizeProvider.subscribe(this.updateComputedProps);
        };

        _proto.componentWillUnmount = function componentWillUnmount() {
          if (this.unsubscribe) this.unsubscribe();
        };

        _proto.render = function render() {
          return React.createElement(ComposedComponent, _extends({}, this.props, this.state.computedProps));
        };

        return ConnectScreenSize;
      }(React.Component);

      Object.defineProperty(ConnectScreenSize, "contextTypes", {
        configurable: true,
        enumerable: true,
        writable: true,
        value: {
          screenSizeProvider: PropTypes.object.isRequired
        }
      });
      return ConnectScreenSize;
    };
  };

  exports.MediaProvider = MediaProvider;
  exports.connectScreenSize = connectScreenSize;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
